# **XIFA**: Accelerated Item Factor Analysis
**XIFA** is a python package for conducting item factor analysis (IFA). 

**XIFA** is build on [**jax**](https://github.com/google/jax). Hence, **XIFA** can run IFA on GPUs and TPUs to speed up the training process. 

In the current version (v0.0.1), the graded response model (GRM) and the generalized partial credit model (GPCM) are supported. 


